"""
********************************************************************************
compas_assembly.plotter
********************************************************************************

.. currentmodule:: compas_assembly.plotter

This package defines various classes and functions for working with assemblies
in Rhino.


Classes
=======

.. autosummary::
    :toctree: generated/
    :nosignatures:

    AssemblyPlotter

"""
from .plotter import AssemblyPlotter

__all__ = [
    'AssemblyPlotter'
]
